@@ -26,7 +26,7 @@ USAGE() {
 check_if_root
 
 #
-ask_and_load_lang_set en
+ask_and_load_lang_set
 #
 if [ $# -ne 1 ]; then
   USAGE
